lua_Debug class final

Inheritance
Implemented types
Available extensions

Constructors

lua_Debug()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
currentline int
(l)
getter/setter pair
event int
getter/setter pair
ftransfer int
(r) index of first value transferred
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
i_ci Pointer<CallInfo>
active function
getter/setter pair
istailcall int
(t)
getter/setter pair
isvararg int
(u)
getter/setter pair
lastlinedefined int
(S)
getter/setter pair
linedefined int
(S)
getter/setter pair
name Pointer<Char>
(n)
getter/setter pair
namewhat Pointer<Char>
(n) 'global', 'local', 'field', 'method'
getter/setter pair
nparams int
(u) number of parameters
getter/setter pair
ntransfer int
(r) number of transferred values
getter/setter pair
nups int
(u) number of upvalues
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
short_src Array<Char>
(S)
getter/setter pair
source Pointer<Char>
(S)
getter/setter pair
srclen int
(S)
getter/setter pair
what Pointer<Char>
(S) 'Lua', 'C', 'main', 'tail'
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited